@@ -1,14 +1,13 @@
 import os
 import os.path
-from pyrustic.threadom import Threadom
+from threadom import Threadom
 from jupitest.host.main_host import MainHost
 from jupitest.host.result import Result
 from jupitest.host.reloader import Reloader
 from jupitest.view.log_window import LogWindow
 from jupitest.view.toolbar import Toolbar
-from jupitest.view.tree import Tree
+from megawidget.tree import Tree
 from jupitest.view.main_view import MainView
-from pyrustic.manager.misc import funcs
 
 
 class MainHostBuilder:
@@ -40,8 +39,7 @@ class TreeBuilder:
 
 class MainViewBuilder:
     def build(self, app):
-        jasonix = funcs.get_manager_jasonix()
-        target = jasonix.data["target"]
+        target = os.getcwd()
         tests_path = os.path.join(target, "tests")
         return MainView(app,
                         Threadom(app.root),
